package Bundle::Rose;

use strict;

our $VERSION = '0.011';

1;

__END__

=head1 NAME

Bundle::Rose - Bundle all modules in the Rose web application construction suite.

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Rose'>

=head1 CONTENTS

Rose::Object
Rose::DateTime
Rose::URI
Rose::HTML::Objects
Rose

=head1 AUTHOR

John C. Siracusa (siracusa@mindspring.com)

=head1 COPYRIGHT

Copyright (c) 2004 by John C. Siracusa.  All rights reserved.  This program is
free software; you can redistribute it and/or modify it under the same terms
as Perl itself.
